import json
class FlaskAppResponseMiddleware(object):
    def __init__(self):
        self.url = 'http://192.168.168.105:5000/browse'
        self.headers = {'Content-Type': 'application/json'}
    def process_request(self, request, spider):
        if request.meta.get('flask_app'):
            if request.url != self.url:
                body = dict(url=request.url, proxy = request.meta.get('proxy'))
                req = request.replace(
                    url=self.url, body=json.dumps(body), method='POST')
                req.headers.update(self.headers)
                return req


# setup.py
from setuptools import setup, find_packages

setup(
    name='bbi-flask-middleware',
    version='0.1.0',  # Initial version
    packages=find_packages(),  # Automatically find the packages to include
    description='A custom middleware library',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Muhammad Irfan',
    license = 'unlicense',
    author_email='irfanliaquat587@gmail.com',
    url='https://github.com/irfan4002/flask-middleware',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
